@@ -2,7 +2,7 @@ import json
 from os.path import join, dirname
 from typing import Dict
 
-from py_dot.core import dicts
+from py_dot.core.dicts import merge
 
 
 def load(json_filename: str, extends_property: str = 'extends') -> Dict:
@@ -20,7 +20,7 @@ def load(json_filename: str, extends_property: str = 'extends') -> Dict:
     extends_length = len(extends_values) - 1
     while extends_length > 0:
         previous_index = extends_length - 1
-        extends_values[previous_index] = dicts.assign(extends_values[extends_length], extends_values[previous_index])
+        extends_values[previous_index] = merge(extends_values[extends_length], extends_values[previous_index], False)
         extends_length -= 1
 
     return extends_values[0]
